Certificats | OiRA
Description: Selon l'approche adoptée par le partenaire national/développeur d’outils OiRA, il peut être possible d'obtenir un certificat pour votre évaluation des risques. Pour plus de détails sur les avantages de ces certificats, veuillez contacter votre partenaire OiRA national.

Thèmes

# Certificats

Selon l'approche adoptée par le partenaire national/développeur d’outils OiRA, il peut être possible d'obtenir un certificat pour votre évaluation des risques. Pour plus de détails sur les avantages de ces certificats, veuillez contacter votre partenaire OiRA national.

Comment obtenir un certificat

## Faire une évaluation complète des risques

À mesure que vous avancez dans votre évaluation des risques, l’OiRA enregistre le travail accompli. Lorsque vous avez évalué un certain nombre de risques, l’outil vous informe sur la possibilité d’obtenir un certificat à l’issue de l’évaluation complète des risques. Chaque partenaire national/développeur d’outils OiRA fixe le seuil (pourcentage) de définition d’une évaluation «complète» des risques. Le certificat est accessible via le bouton «Statut» dans le menu sur le côté gauche de l’écran.

La page de statut indique qu'un certificat est disponible.

## Voir et publier votre certificat

Quand vous cliquerez sur le bouton «Voir le certificat», vous serez invité à saisir le nom de la société qui doit figurer sur le certificat. En fonction des paramètres nationaux, il vous faudra peut-être saisir d’autres données pour garantir que le certificat donne toutes les informations nécessaires.

Saisir toutes les informations nécessaires pour le certificat.

Si vous cochez la case «Rendre public», un lien unique (URL) vers votre certificat apparaît. Copiez ce lien et partagez-le avec les personnes concernées pour prouver que vous avez effectué votre évaluation des risques.

Remarque: Seules les données figurant sur cette page seront rendues publiques. Ce lien n’est pas accessible par le menu du site web de l’OiRA – il vous est propre. Mais en principe, toute personne qui navigue sur Internet pourrait voir le certificat que vous avez créé!

Le certificat montre seulement que vous avez fourni une réponse pour un certain nombre de risques dans l’outil d’évaluation des risques mais ne donne aucune autre information. Les réponses spécifiques données à l’évaluation des risques dans l’outil OiRA ne peuvent être consultées que par vous-même et personne d’autre.

Scroll to top Load toolbar…
Back

## 5-certificates.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More